{%- if show_source and has_source and sourcename %}
  <h3>{{ _('This Page') }}</h3>
  <ul class="this-page-menu">
    <li><a href="{{ pathto('_sources/' + sourcename, true)|e }}"
           rel="nofollow">{{ _('Show Source') }}</a></li>
    <li><a href="https://github.com/mathjax/mathjax-docs/tree/master/{{ pagename }}.rst"
           rel="nofollow">{{ _('Edit Source (on GitHub)') }}</a></li>
  </ul>
{%- endif %}
